@@ -47,7 +47,9 @@ static const char app[] = "ChanIsAvail";
 
 /*** DOCUMENTATION
 	<application name="ChanIsAvail" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>0.4.0</version>
+		</since>
 		<synopsis>
 			Check channel availability
 		</synopsis>
