@@ -68,7 +68,9 @@
 
 /*** DOCUMENTATION
 	<application name="FollowMe" language="en_US">
-		<since><version>1.6.1.0</version></since>
+		<since>
+			<version>1.6.1.0</version>
+		</since>
 		<synopsis>
 			Find-Me/Follow-Me application.
 		</synopsis>
