@@ -41,7 +41,9 @@
 
 /*** DOCUMENTATION
 	<application name="IVRDemo" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			IVR Demo Application.
 		</synopsis>
