@@ -42,7 +42,9 @@
 
 /*** DOCUMENTATION
 	<function name="CDR" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Gets or sets a CDR variable.
 		</synopsis>
@@ -168,7 +170,9 @@
 		</description>
 	</function>
 	<function name="CDR_PROP" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Set a property on a channel's CDR.
 		</synopsis>
