@@ -39,7 +39,9 @@
 
 /*** DOCUMENTATION
 	<function name="ENV" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Gets or sets the environment variable specified.
 		</synopsis>
@@ -102,7 +104,9 @@
 		</description>
 	</function>
 	<function name="STAT" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			Does a check on the specified file.
 		</synopsis>
@@ -129,7 +133,9 @@
 		</description>
 	</function>
 	<function name="FILE" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Read or write text file.
 		</synopsis>
@@ -248,7 +254,9 @@
 		</see-also>
 	</function>
 	<function name="FILE_COUNT_LINE" language="en_US">
-		<since><version>1.8.0</version></since>
+		<since>
+			<version>1.8.0</version>
+		</since>
 		<synopsis>
 			Obtains the number of lines of a text file.
 		</synopsis>
@@ -284,7 +292,9 @@
 		</see-also>
 	</function>
 	<function name="FILE_FORMAT" language="en_US">
-		<since><version>1.8.0</version></since>
+		<since>
+			<version>1.8.0</version>
+		</since>
 		<synopsis>
 			Return the newline format of a text file.
 		</synopsis>
