@@ -46,7 +46,9 @@
 
 /*** DOCUMENTATION
 	<function name="LOCK" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Attempt to obtain a named mutex.
 		</synopsis>
@@ -71,7 +73,9 @@
 		</see-also>
 	</function>
 	<function name="TRYLOCK" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Attempt to obtain a named mutex.
 		</synopsis>
@@ -94,7 +98,9 @@
 		</see-also>
 	</function>
 	<function name="UNLOCK" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Unlocks a named mutex.
 		</synopsis>
