@@ -33,7 +33,9 @@
 
 /*** DOCUMENTATION
 	<function name="IFMODULE" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Checks if an Asterisk module is loaded in memory.
 		</synopsis>
